" Menu Translations:	Slovak
" Translated By:	Martin Lacko <lacko@host.sk>
" Last Change:		2020 Apr 23

" Quit when menu translations have already been done.
if exists("did_menu_trans")
  finish
endif
let did_menu_trans = 1
let s:keepcpo= &cpo
set cpo&vim

scriptencoding iso-8859-2

" Help menu
menutrans &Help			&Pomocník
menutrans &Overview<Tab><F1>	&Prehľad<Tab><F1>
menutrans &User\ Manual		Po&užívateľský\ manuál
menutrans &How-to\ links	&Tipy
menutrans &Find\.\.\.		&Nájsť\.\.\.
menutrans &Credits		Poď&akovanie
menutrans O&rphans		Si&roty
menutrans Co&pying		&Licencia
menutrans &Version		&Verzia
menutrans &About		&O\ programe

" File menu
menutrans &File				&Súbor
menutrans &Open\.\.\.<Tab>:e		&Otvoriť\.\.\.<Tab>:e
menutrans Sp&lit-Open\.\.\.<Tab>:sp	Ot&voriť\ v\ novom\ okne\.\.\.<Tab>:sp
menutrans &New<Tab>:enew		&Nový<Tab>:enew
menutrans &Close<Tab>:close		&Zatvoriť<Tab>:close
menutrans &Save<Tab>:w			&Uložiť<Tab>:w
menutrans Save\ &As\.\.\.<Tab>:sav	Uložiť\ &ako\.\.\.<Tab>:sav
menutrans Split\ &Diff\ with\.\.\.	Otvor&iť\ porovnanie\ v\ novom\ okne\ s\.\.\.
menutrans Split\ Patched\ &By\.\.\.	Otvo&riť\ aktualizované\ s\.\.\.
menutrans &Print			&Tlač
menutrans Sa&ve-Exit<Tab>:wqa		U&ložiť-Koniec<Tab>:wqa
menutrans E&xit<Tab>:qa			&Koniec<Tab>:qa

" Edit menu
menutrans &Edit				&Úpravy
menutrans &Undo<Tab>u			&Späť<Tab>u
menutrans &Redo<Tab>^R			Z&rušiť\ späť<Tab>^R
menutrans Rep&eat<Tab>\.		&Opakovať<Tab>\.
menutrans Cu&t<Tab>"+x			&Vystrihnúť<Tab>"+x
menutrans &Copy<Tab>"+y			&Kopírovať<Tab>"+y
menutrans &Paste<Tab>"+gP		V&ložiť<Tab>"+gP
menutrans Put\ &Before<Tab>[p		Vložiť\ &pred<Tab>[p
menutrans Put\ &After<Tab>]p		Vložiť\ za<Tab>]p
menutrans &Select\ all<Tab>ggVG		Vy&brať\ všetko<Tab>ggVG
menutrans &Delete<Tab>x			Vy&mazať<Tab>x
menutrans &Find\.\.\.			&Nájsť\.\.\.
menutrans Find\ and\ Rep&lace\.\.\.	N&ahradiť\.\.\.
menutrans Settings\ &Window		Mo&žnosti
menutrans &Global\ Settings		&Globálne\ možnosti
menutrans Toggle\ Pattern\ &Highlight<Tab>:set\ hls!	Prepnúť\ paletu\ zvýrazňovania<Tab>:set\ hls!
menutrans Toggle\ &Ignore-case<Tab>:set\ ic!	Prepnúť\ &ignorovanie\ veľkosti<Tab>:set\ ic!
menutrans Toggle\ &Showmatch<Tab>:set\ sm!	Prepnúť\ &ukázať\ zhodu<Tab>:set\ sm!
menutrans &Context\ lines		&Kontextové\ riadky
menutrans &Virtual\ Edit		&Virtuálne\ úpravy
menutrans Never				Nikdy
menutrans Block\ Selection		Blokový\ výber
menutrans Insert\ mode			Režim\ vkladania
menutrans Block\ and\ Insert		Blok\ a\ vkladanie
menutrans Always			Vždy
menutrans Toggle\ Insert\ &Mode<Tab>:set\ im!	Prepnúť\ reži&m\ vkladania<Tab>:set\ im!
menutrans Toggle\ Vi\ C&ompatible<Tab>:set\ cp!	Prepnúť\ vi\ kompatibilitu<Tab>:set\ cp!
menutrans Search\ &Path\.\.\.		Cesta\ &hľadania\.\.\.
menutrans Ta&g\ Files\.\.\.		Ta&gové\ súbory\.\.\.
menutrans Toggle\ &Toolbar		Prepnúť\ &panel
menutrans Toggle\ &Bottom\ Scrollbar	Prepnúť\ spodný\ posuvník
menutrans Toggle\ &Left\ Scrollbar	Prepnúť\ ľavý\ posuvník
menutrans Toggle\ &Right\ Scrollbar	Prepnúť\ pravý\ posuvník
menutrans F&ile\ Settings		Nastavenia\ súboru
menutrans Toggle\ Line\ &Numbering<Tab>:set\ nu!	Prepnúť\ číslova&nie\ riadkov<Tab>:set\ nu!
menutrans Toggle\ &List\ Mode<Tab>:set\ list!		Prepnúť\ režim\ &zoznamu<Tab>:set\ list!
menutrans Toggle\ Line\ &Wrap<Tab>:set\ wrap!		Prepnúť\ z&alamovanie\ riadkov<Tab>:set\ wrap!
menutrans Toggle\ W&rap\ at\ word<Tab>:set\ lbr!	Prepnúť\ za&lamovanie\ slov<Tab>:set\ lbr!
menutrans Toggle\ &expand-tab<Tab>:set\ et!		Prepnúť\ rozšír&ené\ tabulátory<Tab>:set\ et!
menutrans Toggle\ &auto-indent<Tab>:set\ ai!		Prepnúť\ automatické\ &odsadzovanie<Tab>:set\ ai!
menutrans Toggle\ &C-indenting<Tab>:set\ cin!		Prepnúť\ &C-odsadzovanie<Tab>:set\ cin!
menutrans &Shiftwidth			&Šírka\ šiftu
menutrans Soft\ &Tabstop		&Softvérový\ tabulátor
menutrans Te&xt\ Width\.\.\.		Šírka\ te&xtu\.\.\.
menutrans &File\ Format\.\.\.		&Formát\ súboru\.\.\.
menutrans C&olor\ Scheme		Far&ebná\ schéma

" Programming menu
menutrans &Tools			&Nástroje
menutrans &Jump\ to\ this\ tag<Tab>g^]	&Skočiť\ na\ značku<Tab>g^]
menutrans Jump\ &back<Tab>^T		Sk&očiť\ späť<Tab>^T
menutrans Build\ &Tags\ File		&Vytvoriť\ súbor\ značiek
menutrans &Folding			&Vnáranie
menutrans &Enable/Disable\ folds<Tab>zi	Zapnúť/Vypnúť\ vnárani&e<Tab>zi
menutrans &View\ Cursor\ Line<Tab>zv	Zobraziť\ kurzoro&vý\ riadok<Tab>zv
menutrans Vie&w\ Cursor\ Line\ only<Tab>zMzx	Zobraziť\ iba\ kurzorový\ riadok<Tab>zMzx
menutrans C&lose\ more\ folds<Tab>zm	Zatvoriť\ viac\ vnorení<Tab>zm
menutrans &Close\ all\ folds<Tab>zM	Zatvor&iť\ všetky\ vnorenia<Tab>zM
menutrans O&pen\ more\ folds<Tab>zr	O&tvoriť\ viac\ vnorení<Tab>zr
menutrans &Open\ all\ folds<Tab>zR	&Otvoriť\ všetky\ vnorenia<Tab>zR
menutrans Fold\ Met&hod			Metó&da\ vnárania
menutrans M&anual			M&anuálne
menutrans I&ndent			Odsade&nie
menutrans E&xpression			&Výraz
menutrans S&yntax			S&yntax
menutrans &Diff				Roz&diel
menutrans Ma&rker			Zna&čkovač
menutrans Create\ &Fold<Tab>zf		Vyt&voriť\ vnorenie<Tab>zf
menutrans &Delete\ Fold<Tab>zd		V&ymazať\ vnorenie<Tab>zd
menutrans Delete\ &All\ Folds<Tab>zD	Vymazať\ všetky\ vnorenia<Tab>zD
menutrans Fold\ column\ &width		Šírka\ &vkladaného\ stĺpca
menutrans &Diff				&Rozdiely
menutrans &Update			Akt&ualizovať
menutrans &Get\ Block			Zob&rať\ blok
menutrans &Put\ Block			&Vložiť\ blok
menutrans Error\ &Window		Chybové\ &okno
menutrans &Update<Tab>:cwin		Akt&ualizovať<Tab>:cwin
menutrans &Open<Tab>:copen		&Otvoriť<Tab>:copen
menutrans &Close<Tab>:cclose		&Zatvoriť<Tab>:cclose
menutrans &Convert\ to\ HEX<Tab>:%!xxd	&Konvertovať\ do\ HEX<Tab>:%!xxd
menutrans Conve&rt\ back<Tab>:%!xxd\ -r	Konve&rtovať\ späť<Tab>:%!xxd\ -r
menutrans &Make<Tab>:make		&Make<Tab>:make
menutrans &List\ Errors<Tab>:cl		Výpis\ &chýb<Tab>:cl
menutrans L&ist\ Messages<Tab>:cl!	Výp&is\ správ<Tab>:cl!
menutrans &Next\ Error<Tab>:cn		Ďa&lšia\ chyba<Tab>:cn
menutrans &Previous\ Error<Tab>:cp	&Predchádzajúca\ chyba<Tab>:cp
menutrans &Older\ List<Tab>:cold	Sta&rší\ zoznam<Tab>:cold
menutrans N&ewer\ List<Tab>:cnew	Novší\ &zoznam<Tab>:cnew
menutrans Error\ &Window<Tab>:cwin	Chybové\ o&kno<Tab>:cwin
menutrans &Set\ Compiler		Vyberte\ k&ompilátor
menutrans Convert\ to\ HEX<Tab>:%!xxd	Prviesť\ do\ šes&tnástkového\ formátu<Tab>:%!xxd
menutrans Convert\ back<Tab>:%!xxd\ -r	Pr&eviesť\ späť<Tab>:%!xxd\ -r

" Names for buffer menu.
menutrans &Buffers		&Vyrovnávacia\ pamäť
menutrans &Refresh\ menu	Obnoviť
menutrans &Delete		Vymazať
menutrans &Alternate		Zmeniť
menutrans &Next			Ď&alšia
menutrans &Previous		&Predchádzajúca
menutrans [No\ File]		[Žiadny\ súbor]

" Window menu
menutrans &Window			&Okná
menutrans &New<Tab>^Wn			&Nové<Tab>^Wn
menutrans S&plit<Tab>^Ws		&Rozdeliť<Tab>^Ws
menutrans Sp&lit\ To\ #<Tab>^W^^	Ro&zdeliť\ na\ #<Tab>^W^^
menutrans Split\ &Vertically<Tab>^Wv	Rozdeliť\ &vertikálne<Tab>^Wv
menutrans Split\ File\ E&xplorer	Otvoriť\ pri&eskumníka
menutrans &Close<Tab>^Wc		Zatvor&iť<Tab>^Wc
menutrans Close\ &Other(s)<Tab>^Wo	Zatvoriť\ i&né<Tab>^Wo
menutrans Move\ &To			Presunú&ť
menutrans &Top<Tab>^WK			Na&hor<Tab>^WK
menutrans &Bottom<Tab>^WJ		Nado&l<Tab>^WJ
menutrans &Left\ side<Tab>^WH		V&ľavo<Tab>^WJ
menutrans &Right\ side<Tab>^WL		Vprav&o<Tab>^WL
menutrans Ne&xt<Tab>^Ww			Ď&alšie<Tab>^Ww
menutrans P&revious<Tab>^WW		&Predchádzajúce<Tab>^WW
menutrans &Equal\ Size<Tab>^W=		Rovnaká\ výš&ka<Tab>^W=
menutrans &Max\ Height<Tab>^W_		&Maximálna\ výška<Tab>^W_
menutrans M&in\ Height<Tab>^W1_		Minimálna\ vý&ška<Tab>^W1_
menutrans Max\ &Width<Tab>^W\|		Maximálna\ šírka<Tab>^W\|
menutrans Min\ Widt&h<Tab>^W1\|		Minimálna\ širka<Tab>^W1\|
menutrans Rotate\ &Up<Tab>^WR		Rotova&ť\ nahor<Tab>^WR
menutrans Rotate\ &Down<Tab>^Wr		Rotovať\ na&dol<Tab>^Wr
menutrans Select\ Fo&nt\.\.\.		Vy&brať\ písmo\.\.\.

" The popup menu
menutrans &Undo			&Späť
menutrans Cu&t			&Vystrihnúť
menutrans &Copy			&Kopírovať
menutrans &Paste		V&ložiť
menutrans &Delete		V&ymazať
menutrans Select\ Blockwise	Vybrať\ blokovo
menutrans Select\ &Word		Vybrať\ sl&ovo
menutrans Select\ &Line		Vybrať\ &riadok
menutrans Select\ &Block	Vybrať\ &blok
menutrans Select\ &All		Vybrať\ vš&etko

" The GUI toolbar
if has("toolbar")
  if exists("*Do_toolbar_tmenu")
    delfun Do_toolbar_tmenu
  endif
  fun Do_toolbar_tmenu()
    tmenu ToolBar.Open		Otvoriť súbor
    tmenu ToolBar.Save		Uložiť súbor
    tmenu ToolBar.SaveAll	Uložiť všetky
    tmenu ToolBar.Print		Tlač
    tmenu ToolBar.Undo		Späť
    tmenu ToolBar.Redo		Opakovať
    tmenu ToolBar.Cut		Vystrihnúť
    tmenu ToolBar.Copy		Kopírovať
    tmenu ToolBar.Paste		Vložiť
    tmenu ToolBar.Find		Nájsť...
    tmenu ToolBar.FindNext	Nájsť ďalšie
    tmenu ToolBar.FindPrev	Nájsť predchádzajúce
    tmenu ToolBar.Replace	Nahradiť...
    if 0	" disabled; These are in the Windows menu
      tmenu ToolBar.New		Nové okno
      tmenu ToolBar.WinSplit	Rozdeliť okno
      tmenu ToolBar.WinMax	Maximalizovať okno
      tmenu ToolBar.WinMin	Minimalizovať okno
      tmenu ToolBar.WinVSplit	Rozdeliť okno vertikálne
      tmenu ToolBar.WinMaxWidth	Maximalizovať šírku okna
      tmenu ToolBar.WinMinWidth	Minimalizovať šírku okna
      tmenu ToolBar.WinClose	Zatvoriť okno
    endif
    tmenu ToolBar.LoadSesn	Načítať sedenie
    tmenu ToolBar.SaveSesn	Uložiť sedenie
    tmenu ToolBar.RunScript	Spustiť skript
    tmenu ToolBar.Make		Spustiť make
    tmenu ToolBar.Shell		Spustiť šel
    tmenu ToolBar.RunCtags	Spustiť ctags
    tmenu ToolBar.TagJump	Skočiť na tag pod kurzorom
    tmenu ToolBar.Help		Pomocník
    tmenu ToolBar.FindHelp	Nájsť pomocníka k...
  endfun
endif

" Syntax menu
menutrans &Syntax		&Syntax
menutrans Set\ '&syntax'\ only	Nastaviť\ iba\ 'syntax'
menutrans Set\ '&filetype'\ too	Nastaviť\ aj\ 'filetype'
menutrans &Off			&Vypnúť
menutrans &Manual		&Ručne
menutrans A&utomatic		A&utomaticky
" menutrans o&n\ (this\ file)	&Zapnúť\ (pre\ tento\ súbor)
" menutrans o&ff\ (this\ file)	Vyp&núť\ (pre\ tento\ súbor )
menutrans on/off\ for\ &This\ file	Zapnúť/vypnúť\ pre\ &tento\ súbor
menutrans Co&lor\ test		Test\ &farieb
menutrans &Highlight\ test	&Test\ zvýrazňovania
menutrans &Convert\ to\ HTML	&Previesť\ do\ HTML

let &cpo = s:keepcpo
unlet s:keepcpo
